cython_ipp - Cython definitions for Intel IPP library
=====================================================

This package contains `Cython <http://cython.org/>`_ includes (``*.pxd``) files
required to use the `Intel Integrated Performance Primitives
(Intel IPP) <https://software.intel.com/en-us/intel-ipp>`_ library from Cython.
